@@ -686,7 +686,7 @@ def text_tweets_features_extraction(data_tweets):
     screen_name_mention_user = []
     tweets = []
     tweets_url = 0
-    num_tw_day = 1
+    num_tw_day = 0
     is_RT=0
     is_RT_list= []
     screen_name_mention = []
@@ -1115,28 +1115,28 @@ def text_to_list_features_conversor (data):
         data["retweet_tweets_list"].iloc[index] = ast.literal_eval(data.loc[index,"retweet_tweets_list"])
         data["tw_per_day_list"].iloc[index] = ast.literal_eval(data.loc[index,"tw_per_day_list"])
         data["text_tweets_days_list"].iloc[index] = data.loc[index,"text_tweets_days_list"].replace('"', "'").replace("], [","?#??").strip("[]'").split("?#??")
+        
         list_day = []                                                                                
         list_text_tweets_day = []
         list_tweet_date_days = []
         list_RT_days = []
         list_lang_days = []
         text_days = data.loc[index,"tw_day_list"].strip("][").replace(")", ")??").split("??, ")
+        
         tweet_date_days = data.loc[index,"tweet_date_days_list"].replace("], [","???").split("???")
         RT_days = data.loc[index, "RT_days_list"].strip("[]").split("], [")
         lang_days = data.loc[index, "lang_days_list"].strip("[]").split("], [")
         
         for i in range(len(text_days)):
-            #print(i)
             tweet_date_day = tweet_date_days[i].replace("), ",")??").strip("[]").split("??")
-            text_tweets_day = data["text_tweets_days_list"].iloc[index][i].replace("', '","¿¿??").strip("[]'").split("¿¿??")
+            text_tweets_day = data["text_tweets_days_list"].iloc[index][i].replace('"', "'").replace("¿¿??##%', '","¿¿??##%").strip("[]'").split("¿¿??##%")[:-1]
             if len(RT_days[i])==1:
                  RT_day = list(RT_days[i])
             else:
                 RT_day = list(ast.literal_eval(str(RT_days[i])))
             lang_day = list(ast.literal_eval(lang_days[i]))
             list_tweet_date_day = []
-            for j in range(len(tweet_date_day)):
-                
+            for j in range(len(tweet_date_day)):                
                 if(tweet_date_day == ["'Empty'"]):
                     list_tweet_date_day.append("Empty")
                 else:
@@ -1181,12 +1181,12 @@ def separate_text_tweets_feature(df_metadata):
       RT_text_tweets_day = []
       if (len(data_tweets) ==1) & (len(data_tweets[0])==3):
         try:
-          text_tweets_days.append(data_tweets[i]["text"])
+          text_tweets_days.append(data_tweets[i]["text"]+"¿¿??##%")
           lang_text_tweets_days.append(data_tweets[i]["lang"])
           RT_text_tweets_days.append(str(data_tweets[i]["RT"]))
         except:
           for j in range(len(data_tweets[i])):
-            text_tweets_day.append(data_tweets[i][j]["text"])
+            text_tweets_day.append(data_tweets[i][j]["text"]+"¿¿??##%")
             lang_text_tweets_day.append(data_tweets[i][j]["lang"])
             RT_text_tweets_day.append(str(data_tweets[i][j]["RT"]))
           text_tweets_days.append(text_tweets_day)
@@ -1194,7 +1194,7 @@ def separate_text_tweets_feature(df_metadata):
           RT_text_tweets_days.append(RT_text_tweets_day) 
       else:
         for j in range(len(data_tweets[i])):
-          text_tweets_day.append(data_tweets[i][j]["text"])
+          text_tweets_day.append(data_tweets[i][j]["text"]+"¿¿??##%")
           lang_text_tweets_day.append(data_tweets[i][j]["lang"])
           RT_text_tweets_day.append(str(data_tweets[i][j]["RT"]))
         text_tweets_days.append(text_tweets_day)
